@@ -37,8 +37,8 @@ class Q_DECL_EXPORT ActionEditWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit ActionEditWidget(const QString &configName, QWidget *parent = 0);
-    virtual ~ActionEditWidget();
+    explicit ActionEditWidget(const QString &configName, QWidget *parent = nullptr);
+    ~ActionEditWidget() override;
 
     QString configName() const;
 
